CipherStashConfigFile

Struct CipherStashConfigFile 

pub struct CipherStashConfigFile { /* private fields */ }
Represents the standard configuration file usually named cipherstash.toml.

The file contains 2 sections: encrypt and auth.

encrypt section

It contains an encrypt which specifies the client ID and an optional default keyset ID. If not provided and the client is only bound to a single keyset, the client will use that keyset. Otherwise it will throw an error.

auth section

The auth section specifies what workspace to use. How to authenticate to that workspace is specified in the cipherstash.secret.toml file.

The workspace can be specified by either a Crn or a WorkspaceId and Region. The Crn is the preferred method. Note that regions must include the cloud provider (e.g. us-west-1.aws).

Example

[encrypt]
client_id = "1792d1b2-ae14-4d49-ba26-5dcc5a36a716"
default_keyset_id = "1792d1b2-ae14-4d49-ba26-5dcc5a36a716"

[auth]
workspace_crn = "crn:us-west-1.aws:E4UMRN47WJNSMAKR"

Or, using the workspace ID and region:

[encrypt]
client_id = "1792d1b2-ae14-4d49-ba26-5dcc5a36a716"
default_keyset_id = "1792d1b2-ae14-4d49-ba26-5dcc5a36a716"

[auth]
workspace_id = "R7MMSPNCFRY7ZBNH"
region = "us-west-1.aws"

Note that client_key is not allowed in this file. Instead, the client key should be stored in the cipherstash.secret.toml file or set as an environment variable, CS_CLIENT_KEY.

To create a new configuration file, use the CipherStashConfigFileBuilder.

Implementations



impl CipherStashConfigFile

pub const DEFAULT_FILE_NAME: &'static str = "cipherstash.toml"

pub fn persist(self, file_path: impl AsRef<Path>) -> Result<(), ConfigError>

pub fn env_data(&self) -> Result<HashMap<&'static str, String>, ConfigError>

Return the configuration to use in env file for docker-compose. Returns a map of environment variables to set.

Includes:

  • CS_CLIENT_ID
  • CS_DEFAULT_KEYSET_ID (if set)
  • CS_WORKSPACE_CRN (if set)
  • CS_WORKSPACE_ID (if set)
  • CS_REGION (if set)

Note that this doesn’t perform any consistency validation (e.g. if both workspace_crn and workspace_id are set) as this will be done by the config builder when it is created.

pub fn display_env(self, writer: &mut impl Write) -> Result<(), Error>

Writes the configuration to the given writer as environment variables. See Self::env_data for the list of environment variables.