CipherStashConfigFileBuilder

Struct CipherStashConfigFileBuilder 

pub struct CipherStashConfigFileBuilder { /* private fields */ }
Builder (with a terribly long, Java like name) for the cipherstash.toml configuration file (used by stash CLI).

This is a builder for the cipherstash.toml configuration file.

Config settings

The following settings are available:

  • client_id: The client ID to use.
  • default_keyset_id: The default keyset ID to use.
  • workspace_crn: The workspace CRN to use.
  • workspace_id: The workspace ID to use.
  • region: The region to use.
  • meta: A comment to add to the top of the configuration file.

Specifying the workspace

The workspace can be specified by either a Crn or a WorkspaceId and Region. The Crn is the preferred method. Note that regions must include the cloud provider (e.g. us-west-1.aws).

Implementations



impl CipherStashConfigFileBuilder

pub fn new() -> Self

pub fn with_client_id(self, client_id: impl Into<String>) -> Self

pub fn with_default_keyset_id( self, default_keyset_id: impl Into<String>, ) -> Self

pub fn with_workspace_crn(self, crn: Crn) -> Self

pub fn with_workspace_id(self, workspace_id: WorkspaceId) -> Self

pub fn with_region(self, region: Region) -> Self

pub fn with_meta_opt<S: Into<String>>(self, meta: Option<S>) -> Self

Adds a comment to the top of the configuration file. Like Self::with_meta, but accepts an Option.

If None is passed, no comment will be added.

pub fn with_meta(self, meta: impl Into<String>) -> Self

Adds a comment to the top of the configuration file.

pub fn try_build(self) -> Result<CipherStashConfigFile, ConfigError>

Attempt to build a CipherStashConfigFile from the current state of the builder. It will error if any required fields are missing (specifically client_id and workspace_crn).