Struct CipherStashSecretConfigFile
pub struct CipherStashSecretConfigFile { /* private fields */ }Expand description
Represents the cipherstash.secret.toml configuration file.
To create a new instance of this struct, use the CipherStashSecretConfigFileBuilder.
Implementations
impl CipherStashSecretConfigFile
impl CipherStashSecretConfigFile
pub const DEFAULT_FILE_NAME: &'static str = "cipherstash.secret.toml"
pub fn persist(self, file_path: impl AsRef<Path>) -> Result<(), ConfigError>
pub fn persist(self, file_path: impl AsRef<Path>) -> Result<(), ConfigError>
Save the configuration to the given path.
pub fn env_data(&self) -> Result<HashMap<&'static str, String>, ConfigError>
pub fn env_data(&self) -> Result<HashMap<&'static str, String>, ConfigError>
Return the configuration values for use in env file for docker-compose.
Returns a HashMap with the keys CS_CLIENT_KEY and CS_CLIENT_ACCESS_KEY.
The response is wrapped in a Result to match the behavior of the env_data method on CipherStashConfigFile.
pub fn display_env(self) -> String
pub fn display_env(self) -> String
Returns the configuration as an set of environment variables formatted as a single string.