Struct CipherStashSecretConfigFileBuilder
pub struct CipherStashSecretConfigFileBuilder { /* private fields */ }Expand description
Builder (with a terribly long, Java like name) for the cipherstash.secret.toml configuration file (used by stash CLI).
Implementations
impl CipherStashSecretConfigFileBuilder
impl CipherStashSecretConfigFileBuilder
pub fn new() -> Self
pub fn new() -> Self
Create a new builder.
pub fn with_client_key(self, client_key: ClientKey) -> Self
pub fn with_client_key(self, client_key: ClientKey) -> Self
Set the client key.
pub fn with_access_key(self, access_key: String) -> Self
pub fn with_access_key(self, access_key: String) -> Self
Set the access key.
pub fn with_meta_opt<S: Into<String>>(self, meta: Option<S>) -> Self
pub fn with_meta_opt<S: Into<String>>(self, meta: Option<S>) -> Self
Adds a comment to the top of the configuration file.
Like Self::with_meta, but accepts an Option.
If None is passed, no comment will be added.
pub fn with_meta(self, meta: impl Into<String>) -> Self
pub fn with_meta(self, meta: impl Into<String>) -> Self
Adds a comment to the top of the configuration file.
pub fn try_build(self) -> Result<CipherStashSecretConfigFile, ConfigError>
pub fn try_build(self) -> Result<CipherStashSecretConfigFile, ConfigError>
Attempt to build the CipherStashSecretConfigFile.
It will error if the client key is missing or invalid.
NOTE: This method does not currently validate the access key.