FileSource

Struct FileSource 

pub struct FileSource<T, const REQUIRED: bool = true>(/* private fields */);
Specifies a configuration source that reads from a file and deserializes it into a type, T.

Optional files

Normally, if the file is not found, the source will return an error. You can mark the source as optional to ignore the error.

let source = FileSource::<CipherStashConfigFile>::default().optional();

Alternatively, you can specify that a file is required using the REQUIRED type parameter:

let source = FileSource::<CipherStashConfigFile, true>::default();

Specifying a path

By default, the file is loaded from the current working directory. You can specify the directory path with the with_path method.

// Load the file from `some/place/cipherstash.toml`
// Ignore if the file is not found
let source = FileSource::<CipherStashConfigFile>::default()
    .with_path("some/place")
    .optional();

Specifying a filename

You can also specify the filename to use with the with_filename method.

// Load the file from `some/place/myconfig.toml`
let source = FileSource::<CipherStashConfigFile>::default()
   .with_filename("myconfig.toml");

Built in file sources

The following built-in file sources are available:

  • [CipherStashConfigFile]: Loads the cipherstash.toml file.
  • [CipherStashSecretConfigFile]: Loads the cipherstash_secret.toml file.
  • [UserConfigSource]: Loads the config.toml file normally found in ~/.cipherstash/.

See [CipherStashConfigFile] and [CipherStashSecretConfigFile] for details on the configuration files.

Custom file sources

To create a custom file source, implement the IntoFileSource trait.

use cipherstash_client::config::{IntoFileSource, FileSource};
use std::path::PathBuf;
use cts_common::Crn;
use serde::{Deserialize, Serialize};

#[derive(Debug, Serialize, Deserialize)]
pub struct MyConfig {
    workspace_crn: Crn,
}

impl IntoFileSource for MyConfig {
    fn default_path() -> PathBuf {
        PathBuf::from("~/.cipherstash/")
    }

    fn filename() -> String {
        "myconfig.toml".to_string()
    }
}

Implementations



impl<T, const REQUIRED: bool> FileSource<T, REQUIRED>
where T: IntoFileSource,

pub fn save(&self, value: T) -> Result<(), ConfigError>
where T: Serialize,

pub fn with_path(self, path: impl Into<PathBuf>) -> Self

Specify the path of the file to load instead of the one returned via IntoFileSource::default_path.

Example
use cipherstash_client::config::{FileSource, UserConfigSource};

FileSource::<UserConfigSource>::default()
    .with_path("some_dir/myconfig.toml");

pub fn with_path_opt(self, path: Option<impl Into<PathBuf>>) -> Self

Like Self::with_path, but allows the path to be optional.

pub fn with_filename(self, filename: impl Into<String>) -> Self



impl<T> FileSource<T, true>

pub fn load(&self) -> Result<T, ConfigError>

pub fn optional(self) -> FileSource<T, false>

Converts the source to an optional source.



impl<T> FileSource<T, false>

pub fn load_opt(&self) -> Result<Option<T>, ConfigError>

pub fn required(self) -> FileSource<T, true>

Converts the source to a required source.