Struct UserConfigSource
pub struct UserConfigSource { /* private fields */ }Expand description
Specifies the format for a user’s configuration file.
Usually located at ~/.cipherstash/config.toml.
See the module-level documentation for more details.
Implementations
impl UserConfigSource
impl UserConfigSource
pub const DEFAULT_FILE_NAME: &'static str = "config.toml"
pub const DEFAULT_FILE_NAME: &'static str = "config.toml"
The default file name for the local configuration file.
pub const DEFAULT_FILE_PATH: &'static str = ".cipherstash"
pub const DEFAULT_FILE_PATH: &'static str = ".cipherstash"
The default file path for the local configuration file (relative to the home directory).
pub fn workspace_crn(&self) -> Option<Crn>
pub fn workspace_crn(&self) -> Option<Crn>
Returns the workspace CRN if set.
pub fn set_current_workspace(&mut self, crn: Crn)
pub fn set_current_workspace(&mut self, crn: Crn)
Sets the current workspace CRN.