IndexTerm

Enum IndexTerm 

pub enum IndexTerm {
    Binary(Vec<u8>),
    BinaryVec(Vec<Vec<u8>>),
    BitMap(Vec<u16>),
    OreFull(Vec<u8>),
    OreArray(Vec<Vec<u8>>),
    OreLeft(Vec<u8>),
    OpeFixed(Vec<u8>),
    OpeVariable(Vec<u8>),
    SteVecSelector(TokenizedSelector<16>),
    SteVecTerm(EncryptedSteVecTerm),
    SteQueryVec(SteQueryVec<16>),
    Null,
}

Variants



Binary(Vec<u8>)



BinaryVec(Vec<Vec<u8>>)



BitMap(Vec<u16>)



OreFull(Vec<u8>)

Represents a full ORE Ciphertext (both left and right)



OreArray(Vec<Vec<u8>>)

Array of FullOre terms



OreLeft(Vec<u8>)

Represents a Left ORE Ciphertext



OpeFixed(Vec<u8>)

Fixed-width CLWW OPE ciphertext for numeric plaintexts (65 bytes for u64).



OpeVariable(Vec<u8>)

Variable-length CLWW OPE ciphertext for string plaintexts.



SteVecSelector(TokenizedSelector<16>)



SteVecTerm(EncryptedSteVecTerm)



SteQueryVec(SteQueryVec<16>)



Null

NULL index field

Implementations



impl IndexTerm

pub fn as_binary(self) -> Option<Vec<u8>>

pub fn as_binary_vec(self) -> Option<Vec<Vec<u8>>>

Get the index term as a vector of binary terms. If the term is a single binary term, it will be wrapped in a vec.