Encryption

Struct Encryption 

pub struct Encryption<C = AutoStrategy> { /* private fields */ }

Implementations



impl<Creds> Encryption<Creds>
where Creds: AuthStrategyBounds, for<'a> &'a Creds: AuthStrategy,

pub fn new(root_key: IndexKey, client: ZeroKMSWithClientKey<Creds>) -> Self

pub async fn encrypt<T: Into<BytesWithDescriptor>>( &self, items: impl IntoIterator<Item = T>, ) -> Result<Vec<EncryptedRecord>, EncryptionError>

pub async fn encrypt_single( &self, target: PlaintextTarget, ) -> Result<EncryptedRecord, EncryptionError>

pub async fn decrypt_single( &self, ciphertext: EncryptedRecord, ) -> Result<Plaintext, EncryptionError>

pub async fn maybe_decrypt_hex<I, C>( &self, ciphertexts: I, ) -> Result<Vec<Option<Plaintext>>, EncryptionError>
where I: IntoIterator<Item = Option<C>>, C: AsRef<[u8]>,

Like decrypt but doesn’t expect all values to be decryptable. This only means that a given input is None or the slice is not a serialized EncryptedRecord. In the future this could also cover cases where the caller is not authorized to decrypt a given value.

As it stands, this function will return an Error if any valid ciphertexts fail to decrypt.

Items in the returned vec wil be in the same order as the input but any values that are unable to be decrypted will be returned as None.

Encrypted records must be encoded with hex.

pub async fn decrypt( &self, ciphertexts: impl IntoIterator<Item = EncryptedRecord>, ) -> Result<Vec<Plaintext>, EncryptionError>

pub fn index( &self, value: &Plaintext, index_type: &IndexType, ) -> Result<IndexTerm, EncryptionError>

pub fn index_all( &self, target: &PlaintextTarget, ) -> Result<Vec<IndexTerm>, EncryptionError>

pub fn compound_index( &self, index: &CompoundIndex<impl ComposableIndex + Send>, input: impl Into<ComposablePlaintext>, salt: Option<impl AsRef<[u8]>>, term_length: usize, ) -> Result<IndexTerm, EncryptionError>

pub fn compound_query( &self, index: &CompoundIndex<impl ComposableIndex + Send>, input: impl Into<ComposablePlaintext>, salt: Option<impl AsRef<[u8]>>, term_length: usize, ) -> Result<IndexTerm, EncryptionError>

pub fn index_for_operator( &self, value: &Plaintext, index_type: &IndexType, operator: &Operator, cast_type: &ColumnType, ) -> Result<IndexTerm, EncryptionError>