Struct PlaintextTarget
pub struct PlaintextTarget {
pub plaintext: Plaintext,
pub config: ColumnConfig,
pub operator: Option<Operator>,
pub context: Vec<Context>,
}Expand description
Convenience type that represents a Param which will be mapped using config.
config will always be present but operator may be None in this case.
Fields
plaintext: Plaintextconfig: ColumnConfigoperator: Option<Operator>context: Vec<Context>Implementations
impl PlaintextTarget
impl PlaintextTarget
pub fn new(plaintext: impl Into<Plaintext>, config: ColumnConfig) -> Self
pub fn new_with_operator( plaintext: impl Into<Plaintext>, config: ColumnConfig, operator: Option<Operator>, ) -> Self
pub fn payload(&self) -> BytesWithDescriptor
pub fn payload(&self) -> BytesWithDescriptor
Convert the Plaintext into a byte array and attach the descriptor to it.
pub fn config(&self) -> &ColumnConfig
pub fn with_context(self, context: Context) -> Self