Enum Region
pub enum Region {
Aws(AwsRegion),
}Expand description
Defines the region of a CipherStash service.
A region in CipherStash is defined by the region identifier and the provider separated by a dot.
For example, us-west-2.aws is a valid region identifier and refers to the AWS region us-west-2.
Variants
Implementations
Sourceimpl Region
impl Region
pub fn all() -> Vec<Region>
Sourcepub fn new(identifier: &str) -> Result<Region, RegionError>
pub fn new(identifier: &str) -> Result<Region, RegionError>
Creates a new region from an identifier.
Region identifiers are in the format <region>.<provider>.
For example, us-west-2.aws is a valid region identifier.
Example
use cts_common::{AwsRegion, Region};
let region = Region::new("us-west-2.aws").unwrap();
assert_eq!(region, Region::Aws(AwsRegion::UsWest2));Sourcepub fn aws(identifier: &str) -> Result<Region, RegionError>
pub fn aws(identifier: &str) -> Result<Region, RegionError>
Creates a new AWS region from an identifier. Note that this is not the complete list of AWS regions, only the ones that are currently supported by CipherStash.
Example
use cts_common::{Region, AwsRegion};
let region = Region::aws("us-west-2").unwrap();
assert_eq!(region, Region::Aws(AwsRegion::UsWest2));pub fn identifier(&self) -> String
pub fn name(&self) -> &'static str