decrypt_eql_fallible

Function decrypt_eql_fallible 

pub async fn decrypt_eql_fallible<'a, C>(
    cipher: Arc<ScopedCipher<C>>,
    ciphertexts: impl IntoIterator<Item = EqlCiphertext>,
    opts: &EqlDecryptOpts<'a>,
) -> Result<Vec<Result<Plaintext, EqlError>>, EqlError>
Like decrypt_eql but decryption failure of one or more ciphertexts does not fail the entire operation. Instead, a decryption result (success or failure) is returned for every ciphertext.

Per-Item Errors

The following conditions produce per-item Err results without aborting:

  • Empty STE vector on a EqlCiphertext::SteVec payload: Returns Err(EqlError::MissingCiphertext).
  • Decryption failure: Returns Err with the underlying decryption error.

Operation-Level Errors

Only a failure to retrieve the access token will result in the entire operation failing.