Struct EqlEncryptOpts
pub struct EqlEncryptOpts<'a> {
pub keyset_id: Option<Uuid>,
pub lock_context: Cow<'a, [Context]>,
pub unverified_context: Option<Cow<'a, UnverifiedContext>>,
pub index_types: Option<Cow<'a, [IndexType]>>,
pub decryption_policy: Option<DecryptionPolicy>,
}Expand description
Options for EQL encryption operations.
Configuration for encrypt_eql, controlling which keyset to use, the lock context for key
wrapping, and which indexes to generate.
Fields
keyset_id- Optional keyset UUID; ifNone, uses the cipher’s default keysetlock_context- Context information for wrapping data encryption keysunverified_context- Optional unverified context for additional metadataindex_types- Optional filter to generate only specific index types instead of all configured indexesdecryption_policy- Optional decryption policy for OR-style lock context
Examples
use cipherstash_client::eql::EqlEncryptOpts;
use std::borrow::Cow;
// Use default options (all indexes, default keyset)
let opts = EqlEncryptOpts::default();
// Or customize
let opts = EqlEncryptOpts {
keyset_id: None,
lock_context: Cow::Owned(vec![]),
unverified_context: None,
index_types: Some(Cow::Owned(vec![IndexType::Ore])), // Generate only ORE indexes
decryption_policy: None,
};Fields
keyset_id: Option<Uuid>Keyset to use for all encryption operations.
When set to None, encryption uses the keyset associated with the ZeroKMS client.
lock_context: Cow<'a, [Context]>The lock context to use for encryption operations.
unverified_context: Option<Cow<'a, UnverifiedContext>>Optional unverified context for additional metadata.
index_types: Option<Cow<'a, [IndexType]>>Optional filter to generate only specific index types.
When present, generate only the specified index types instead of all index types specified in the column configuration.
decryption_policy: Option<DecryptionPolicy>Optional decryption policy for OR-style lock context.
When set, tag_version = 1 is used instead of the lock_context field.