Struct UnverifiedContext
pub struct UnverifiedContext(pub HashMap<String, Option<UnverifiedContextValue>>);Expand description
A loose, schema‑free context map that can carry scalars, arrays, and nested maps.
Tuple Fields
0: HashMap<String, Option<UnverifiedContextValue>>Trait Implementations
Sourceimpl Clone for UnverifiedContext
impl Clone for UnverifiedContext
Sourcefn clone(&self) -> UnverifiedContext
fn clone(&self) -> UnverifiedContext
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for UnverifiedContext
impl Debug for UnverifiedContext
Sourceimpl Default for UnverifiedContext
impl Default for UnverifiedContext
Sourcefn default() -> UnverifiedContext
fn default() -> UnverifiedContext
Returns the “default value” for a type. Read more
Sourceimpl<'de> Deserialize<'de> for UnverifiedContext
impl<'de> Deserialize<'de> for UnverifiedContext
Sourcefn deserialize<__D>(
__deserializer: __D,
) -> Result<UnverifiedContext, <__D as Deserializer<'de>>::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(
__deserializer: __D,
) -> Result<UnverifiedContext, <__D as Deserializer<'de>>::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl PartialEq for UnverifiedContext
impl PartialEq for UnverifiedContext
Sourcefn eq(&self, other: &UnverifiedContext) -> bool
fn eq(&self, other: &UnverifiedContext) -> bool
Tests for
self and other values to be equal, and is used by ==.Sourceimpl Serialize for UnverifiedContext
impl Serialize for UnverifiedContext
Sourcefn serialize<__S>(
&self,
__serializer: __S,
) -> Result<<__S as Serializer>::Ok, <__S as Serializer>::Error>where
__S: Serializer,
fn serialize<__S>(
&self,
__serializer: __S,
) -> Result<<__S as Serializer>::Ok, <__S as Serializer>::Error>where
__S: Serializer,
Serialize this value into the given Serde serializer. Read more
impl StructuralPartialEq for UnverifiedContext