Struct WorkspaceId
pub struct WorkspaceId(/* private fields */);Expand description
A unique identifier for a workspace. Workspace IDs are 10-byte random strings formatted in base32.
Internally, the workspace ID is stored as an ArrayString with a maximum length of 20 characters.
This means that values work entirely on the stack and implement the Copy trait.
Example
use cts_common::WorkspaceId;
let workspace_id = WorkspaceId::generate().unwrap();
println!("Workspace ID: {}", workspace_id);A WorkspaceId can be converted from a string but will fail if the string is not a valid workspace ID.
use cts_common::WorkspaceId;
let workspace_id = WorkspaceId::try_from("JBSWY3DPEHPK3PXP").unwrap();
// This will fail because the string is not a valid workspace ID
let workspace_id = WorkspaceId::try_from("invalid-id").unwrap_err();Comparison
Workspace IDs can be compared to strings.
use cts_common::WorkspaceId;
let workspace_id = WorkspaceId::try_from("E4UMRN47WJNSMAKR").unwrap();
assert_eq!(workspace_id, "E4UMRN47WJNSMAKR");Use with Diesel
When the server feature is enabled, WorkspaceId can be used with Diesel in models and queries.
The underlying data type is a Text column in the database.
Implementations
Sourceimpl WorkspaceId
impl WorkspaceId
Sourcepub fn generate() -> Result<WorkspaceId, WorkspaceIdGenerationError>
pub fn generate() -> Result<WorkspaceId, WorkspaceIdGenerationError>
Generate a new workspace ID with an entropy source.
To use a SafeRand instance, use the Generatable::random method instead.
pub fn as_str(&self) -> &str