Enum ClientKeysetId
pub enum ClientKeysetId {
Single(Uuid),
Multiple(Vec<Uuid>),
}Expand description
Struct representing the keyset ids associated with a client which could be a single keyset or multiple keysets.
Variants