Struct CreateClientResponse
pub struct CreateClientResponse {
pub id: Uuid,
pub keyset_id: Uuid,
pub name: String,
pub description: String,
pub client_key: ViturKeyMaterial,
}Expand description
Response message to a CreateClientRequest.
Contains the client_id and the client_key, the latter being a base64 encoded 32 byte key.
The client_key should be considered sensitive and should be stored securely.
Fields
id: UuidThe unique ID of the newly created client.
keyset_id: UuidThe ID of the keyset this client is associated with.
name: StringThe name of the client.
description: StringThe description of the client.
client_key: ViturKeyMaterialBase64-encoded 32-byte key material for the client. Store this securely.