Struct DatasetConfig
pub struct DatasetConfig {
pub tables: UniqueList<TableConfig>,
}Expand description
Struct to manage the config for a given database. At connection time, the Driver will retrieve config from Vitur for the currently connected database
Fields
tables: UniqueList<TableConfig>Implementations
Sourceimpl DatasetConfig
impl DatasetConfig
pub fn init() -> DatasetConfig
pub fn add_table( self, config: TableConfig, ) -> Result<DatasetConfig, ConfigError>
Sourcepub fn has_table<Q>(&self, query: &Q) -> boolwhere
TableConfig: PartialEq<Q>,
pub fn has_table<Q>(&self, query: &Q) -> boolwhere
TableConfig: PartialEq<Q>,
Returns true if a table matches the given query
Sourcepub fn get_table<Q>(&self, query: &Q) -> Option<&TableConfig>where
TableConfig: PartialEq<Q>,
pub fn get_table<Q>(&self, query: &Q) -> Option<&TableConfig>where
TableConfig: PartialEq<Q>,
Finds a table that matches query
Sourcepub fn sort_indexes_by_type(self) -> DatasetConfig
pub fn sort_indexes_by_type(self) -> DatasetConfig
Sorts all indexes by type for each field in each table. Indexes are sorted in place.
This is useful for ensuring that iteration over indexes always occurs in order
by type (instead of the order that they appear in a config file or the order of
ColumnConfig::add_index calls).