EncryptedRecord

Struct EncryptedRecord 

pub struct EncryptedRecord {
    pub iv: Iv,
    pub ciphertext: Vec<u8>,
    pub tag: Vec<u8>,
    pub descriptor: String,
    pub keyset_id: Option<Uuid>,
    pub decryption_policy: Option<DecryptionPolicy>,
}
Represents an encrypted record for storage in the database. Implements serialization and deserialization so you can use it with any serde-compatible format however convenience methods are provided for CBOR, MessagePack, Hex, and Base85 encoding.

Fields

iv: Ivciphertext: Vec<u8>tag: Vec<u8>descriptor: Stringkeyset_id: Option<Uuid>decryption_policy: Option<DecryptionPolicy>

Decryption policy with server-generated MAC (tag_version=1 only).

Implementations



impl EncryptedRecord

pub fn to_vec(&self) -> Result<Vec<u8>, DecryptError>

👎Deprecated since 0.12.4:

Use to_cbor_bytes or to_mp_bytes instead

Serialize the record to a Vec<u8> using CBOR encoding

pub fn to_cbor_bytes(&self) -> Result<Vec<u8>, DecryptError>

Serialize the record to a Vec<u8> using CBOR encoding

pub fn to_mp_bytes(&self) -> Result<Vec<u8>, DecryptError>

Serialize the record to a Vec<u8> using MessagePack encoding

pub fn to_hex(&self) -> Result<String, DecryptError>

👎Deprecated since 0.12.4:

Use to_cbor_hex or to_mp_base85 instead

Serialize the record using CBOR and convert to a hex-encoded string

pub fn to_cbor_hex(&self) -> Result<String, DecryptError>

Serialize the record using CBOR and convert to a hex-encoded string

pub fn to_mp_base85(&self) -> Result<String, DecryptError>

Serialize the record using MessagePack and convert to a base85-encoded string

pub fn from_slice(bytes: &[u8]) -> Result<Self, DecryptError>

👎Deprecated since 0.12.4:

Use from_cbor_bytes or from_mp_bytes instead

Deserialize a record from a slice of bytes encoded using CBOR

pub fn from_cbor_bytes(bytes: &[u8]) -> Result<Self, DecryptError>

Deserialize a record from a slice of bytes encoded using CBOR

pub fn from_mp_bytes(bytes: &[u8]) -> Result<Self, DecryptError>

Deserialize a record from a slice of bytes encoded using MessagePack

pub fn from_hex(hexstr: impl AsRef<[u8]>) -> Result<Self, DecryptError>

👎Deprecated since 0.12.4:

Use from_cbor_hex or from_mp_base85 instead

Deserialize a record from a hex-encoded string of bytes encoded using CBOR

pub fn from_cbor_hex(hexstr: &str) -> Result<Self, DecryptError>

Deserialize a record from a hex-encoded string of bytes encoded using CBOR

pub fn from_mp_base85(base85str: &str) -> Result<Self, DecryptError>

Deserialize a record from a base85-encoded string of bytes encoded using MessagePack

pub fn with_context<'a>(self, context: Context) -> WithContext<'a>

Add a context to the record to prepare it for decryption.