Module encryption
Module for CipherStash encryption schemes and indexers
Modules
Structs
- Bytes
With Descriptor - Decrypt
Options - Encrypted
Entry - One SteVec wire entry:
{s, c}plus an optional orderable term. - Encryption
- Indexed
Array - Indexed
Bool - Indexed
Null - Indexed
Number - Indexed
Object - Indexed
String - Json
Indexer - Indexer for searchable encryption of JSON documents.
- Json
Indexer Options - Configuration for a
JsonIndexer. - Jsonb
Indexer - Structure preserving cryptographic JSONB indexing.
- Match
Indexer - OpeIndexer
- OreIndexer
- Payload
- Plaintext
Target - Convenience type that represents a
Paramwhich will be mapped usingconfig.configwill always be present butoperatormay beNonein this case. - Query
Builder - Scoped
Cipher - A Scoped Cipher is one which has been initialized for a specific keyset. It can be used only to encrypt and decrypt data for that keyset.
- SteQuery
Vec - Represents a vector of query entries.
- SteVec
- Describes a SteVec, which is a vector of encrypted entries used to index JSON.
Nis the length of the selector. - Storage
Builder - Tokenized
Selector - Represents a tokenized selector for a value in a JSON object.
- Type
Parse Error - Unique
Indexer
Enums
- Encrypted
- Represents an encrypted payload that is ready to be stored.
- Encrypted
SteVec Term - The (optional) orderable term carried by a SteVec entry — the ONLY term
kind an entry can carry. Exact matching for every node kind is the
value-inclusive selector’s job (see
[
super::priv_state::value_selector]), so no per-value MAC term (hm) exists on entries. - Encryption
Error - Index
Term - Indexed
Value - An
IndexedValuestructurally mirrors aserde_json::Valueand enhances it with cryptographic search terms. - Jsonb
Indexer Error - Plaintext
- QueryOp
- Query operations for STE-vec indexed columns.
Constants
- VALUE_
ENTRY_ SENTINEL - The plaintext a value entry encrypts: a fixed, versioned sentinel.
Traits
Functions
- is_
value_ entry_ sentinel - True when
bytes(a decrypted entry plaintext) is the value-entry sentinel — i.e. the entry was a value-inclusive selector, not a node.