Struct StorageBuilder
pub struct StorageBuilder<'k, T> { /* private fields */ }Implementations
impl<'k, T> StorageBuilder<'k, T>
impl<'k, T> StorageBuilder<'k, T>
pub fn new(source: T, key: &'k IndexKey, keyset_id: Uuid) -> Self
pub fn index_with<I>(self, index: I) -> Result<Self, EncryptionError>where
for<'t> I: Indexes<'t, T>,
pub fn with_descriptor(self, descriptor: impl Into<String>) -> Self
pub fn with_context(self, context: Context) -> Self
pub fn with_context(self, context: Context) -> Self
Adds context to the record.
pub fn set_context(self, context: Cow<'k, [Context]>) -> Self
pub fn set_context(self, context: Cow<'k, [Context]>) -> Self
Sets the context for the record (replacing any existing context).
pub fn keyset_id(&self) -> Uuid
pub fn descriptor(&self) -> &str
pub fn descriptor(&self) -> &str
Gets the descriptor. An empty string is returned if a descriptor has not been set or if the underlying data is
an SteVec.
Encrypted::SteVec(_) cannot currently have a descriptor set on it, so if one were to be encrypted using a descriptor then decryption would use an empty string which would cause decryption to fail.
This is a limitation of the implementation: an SteVec should have a descriptor but changing it without an
EQL upgrade with a mandatory migration process would break existing encrypted data.
pub fn to_index_terms(self) -> Vec<IndexTerm>