Trait AuthStrategy
pub trait AuthStrategy: Send {
// Required method
fn get_token(
self,
) -> impl Future<Output = Result<ServiceToken, AuthError>> + Send;
}Expand description
A strategy for obtaining access tokens.
Implementations handle all details of authentication, token caching, and
refresh. Callers just call get_token whenever
they need a valid token.
The trait is designed to be implemented for &T, so that callers can use
shared references (e.g. &OAuthStrategy) without consuming the strategy.
Required Methods
Dyn Compatibility
This trait is not dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety", so this trait is not object safe.