Enum Context
pub enum Context {
Tag(String),
Value(String, String),
IdentityClaim(String),
}Expand description
Represents a contextual attribute for a data key which is used to “lock” the key to a specific context. Context attributes are included key tag generation which is in turn used as AAD in the final encryption step in the client. Context attributes should never include any sensitive information.
Variants
Tag(String)
A tag that can be used to identify the key.
Value(String, String)
A key-value pair that can be used to identify the key.
For example, a key-value pair could be ("user_id", "1234").
IdentityClaim(String)
A claim from the identity of the principal that is requesting the key. The claim value is read from the claims list after token verification and prior to key generation.
For example, a claim could be "sub".
Implementations